summaryrefslogtreecommitdiffstats
path: root/kicker
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit9a3f0aacd44fb866833ebcb852df3cd31475cb33 (patch)
tree9f699684624f4e78e13e7dd2393a103cc6fa8274 /kicker
parent341ad02235b9c85cd31782225181ed475b74eaa3 (diff)
downloadtdebase-9a3f0aacd44fb866833ebcb852df3cd31475cb33.tar.gz
tdebase-9a3f0aacd44fb866833ebcb852df3cd31475cb33.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kicker')
-rw-r--r--kicker/applets/clock/clock.cpp22
-rw-r--r--kicker/applets/clock/zone.cpp4
-rw-r--r--kicker/applets/launcher/quickaddappsmenu.cpp2
-rw-r--r--kicker/applets/launcher/quickbutton.cpp2
-rw-r--r--kicker/applets/launcher/quicklauncher.cpp2
-rw-r--r--kicker/applets/media/mediaapplet.cpp6
-rw-r--r--kicker/applets/media/preferencesdialog.cpp4
-rw-r--r--kicker/applets/minipager/pagerbutton.cpp4
-rw-r--r--kicker/applets/naughty/NaughtyApplet.cpp2
-rw-r--r--kicker/applets/naughty/NaughtyProcessMonitor.cpp14
-rw-r--r--kicker/applets/swallow/swallow.cpp2
-rw-r--r--kicker/applets/systemtray/systemtrayapplet.cpp18
-rw-r--r--kicker/extensions/dockbar/dockbarextension.cpp2
-rw-r--r--kicker/extensions/kasbar/kasbar.cpp2
-rw-r--r--kicker/extensions/kasbar/kasbar.h2
-rw-r--r--kicker/extensions/kasbar/kastaskitem.cpp2
-rw-r--r--kicker/kicker/buttons/knewbutton.cpp6
-rw-r--r--kicker/kicker/core/applethandle.cpp4
-rw-r--r--kicker/kicker/core/container_extension.cpp4
-rw-r--r--kicker/kicker/core/containerarea.cpp8
-rw-r--r--kicker/kicker/core/containerarealayout.cpp4
-rw-r--r--kicker/kicker/core/extensionmanager.cpp8
-rw-r--r--kicker/kicker/core/main.cpp2
-rw-r--r--kicker/kicker/core/pluginmanager.cpp4
-rw-r--r--kicker/kicker/kicker-3.4-reverseLayout.cpp2
-rw-r--r--kicker/kicker/plugins/kickoff-beagle-plugin.cpp10
-rw-r--r--kicker/kicker/ui/addapplet.cpp6
-rw-r--r--kicker/kicker/ui/addapplet_mnu.cpp4
-rw-r--r--kicker/kicker/ui/addbutton_mnu.cpp2
-rw-r--r--kicker/kicker/ui/addextension_mnu.cpp2
-rw-r--r--kicker/kicker/ui/appletop_mnu.cpp2
-rw-r--r--kicker/kicker/ui/browser_mnu.cpp14
-rw-r--r--kicker/kicker/ui/exe_dlg.cpp4
-rw-r--r--kicker/kicker/ui/itemview.cpp14
-rw-r--r--kicker/kicker/ui/k_mnu.cpp2
-rw-r--r--kicker/kicker/ui/k_new_mnu.cpp82
-rw-r--r--kicker/kicker/ui/kickoff_bar.cpp4
-rw-r--r--kicker/kicker/ui/query.cpp4
-rw-r--r--kicker/kicker/ui/removeapplet_mnu.cpp2
-rw-r--r--kicker/kicker/ui/removeextension_mnu.cpp2
-rw-r--r--kicker/kicker/ui/service_mnu.cpp34
-rw-r--r--kicker/libkicker/global.cpp2
-rw-r--r--kicker/libkicker/panelbutton.cpp6
-rw-r--r--kicker/menuext/kate/katesessionmenu.cpp2
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.cpp2
-rw-r--r--kicker/menuext/prefmenu/prefmenu.cpp12
-rw-r--r--kicker/menuext/recentdocs/recentdocsmenu.cpp8
-rw-r--r--kicker/menuext/remote/remotemenu.cpp4
-rw-r--r--kicker/menuext/system/systemmenu.cpp2
-rw-r--r--kicker/menuext/tom/tom.cc14
-rw-r--r--kicker/taskbar/taskbar.cpp20
-rw-r--r--kicker/taskbar/taskcontainer.cpp12
-rw-r--r--kicker/taskbar/taskcontainer.h6
-rw-r--r--kicker/taskmanager/tasklmbmenu.cpp2
-rw-r--r--kicker/taskmanager/taskmanager.cpp14
-rw-r--r--kicker/taskmanager/taskmanager.h2
-rw-r--r--kicker/taskmanager/taskrmbmenu.cpp4
57 files changed, 216 insertions, 216 deletions
diff --git a/kicker/applets/clock/clock.cpp b/kicker/applets/clock/clock.cpp
index 2265f801b..6eb40993d 100644
--- a/kicker/applets/clock/clock.cpp
+++ b/kicker/applets/clock/clock.cpp
@@ -806,9 +806,9 @@ void FuzzyClock::drawContents(TQPainter *p)
}
newTimeStr = normalFuzzy[sector];
- int phStart = newTimeStr.tqfind("%");
+ int phStart = newTimeStr.find("%");
if (phStart >= 0) { // protect yourself from translations
- int phLength = newTimeStr.tqfind(" ", phStart) - phStart;
+ int phLength = newTimeStr.find(" ", phStart) - phStart;
// larrosa: we want the exact length, in case the translation needs it,
// in other case, we would cut off the end of the translation.
@@ -821,13 +821,13 @@ void FuzzyClock::drawContents(TQPainter *p)
realHour = 12 - ((_time.hour() + deltaHour) % 12 + 1);
if (realHour==0) {
newTimeStr = normalFuzzyOne[sector];
- phStart = newTimeStr.tqfind("%");
+ phStart = newTimeStr.find("%");
// larrosa: Note that length is the same,
// so we only have to update phStart
}
if (phStart >= 0)
- newTimeStr.tqreplace(phStart, phLength, hourNames[realHour]);
- newTimeStr.tqreplace(0, 1, TQString(newTimeStr.tqat(0).upper()));
+ newTimeStr.replace(phStart, phLength, hourNames[realHour]);
+ newTimeStr.replace(0, 1, TQString(newTimeStr.tqat(0).upper()));
}
} else if (_prefs->fuzzyness() == 3) {
newTimeStr = dayTime[_time.hour() / 3];
@@ -1120,7 +1120,7 @@ int ClockApplet::heightForWidth(int w) const
{
TQString dateStr = _date->text();
// if we're too wide to fit, replace the first non-digit from the end with a space
- int p = dateStr.tqfindRev(TQRegExp("[^0-9]"));
+ int p = dateStr.findRev(TQRegExp("[^0-9]"));
if (p > 0)
{
_date->setText(dateStr.insert(p, '\n'));
@@ -1568,7 +1568,7 @@ void ClockApplet::aboutToShowContextMenu()
}
else
{
- zoneMenu->insertItem(i18n(zone->zone(i).utf8()).tqreplace("_", " "), 500 + i);
+ zoneMenu->insertItem(i18n(zone->zone(i).utf8()).replace("_", " "), 500 + i);
}
}
zoneMenu->setItemChecked(500 + zone->zoneIndex(),true);
@@ -1699,7 +1699,7 @@ void ClockApplet::updateDateLabel(bool reLayout)
if (zone->zoneIndex() != 0)
{
TQString zone_s = i18n(zone->zone().utf8());
- _date->setText(zone_s.mid(zone_s.tqfind('/') + 1).tqreplace("_", " "));
+ _date->setText(zone_s.mid(zone_s.find('/') + 1).replace("_", " "));
_date->setShown(true);
}
else
@@ -1737,7 +1737,7 @@ void ClockApplet::updateKickerTip(KickerTip::Data& data)
if (!activeZone.isEmpty())
{
activeZone = i18n(activeZone.utf8());
- data.subtext.append("<br>").append(activeZone.mid(activeZone.tqfind('/') + 1).tqreplace("_", " "));
+ data.subtext.append("<br>").append(activeZone.mid(activeZone.find('/') + 1).replace("_", " "));
}
}
else
@@ -1760,7 +1760,7 @@ void ClockApplet::updateKickerTip(KickerTip::Data& data)
if (activeIndex == i)
{
- data.message = m_zone.mid(m_zone.tqfind('/') + 1).tqreplace("_", " ");
+ data.message = m_zone.mid(m_zone.find('/') + 1).replace("_", " ");
data.message += " " + _time + "<br>" + _date;
}
else
@@ -1771,7 +1771,7 @@ void ClockApplet::updateKickerTip(KickerTip::Data& data)
}
else
{
- data.subtext += "<b>" + m_zone.mid(m_zone.tqfind('/') + 1).tqreplace("_", " ") + "</b>";
+ data.subtext += "<b>" + m_zone.mid(m_zone.find('/') + 1).replace("_", " ") + "</b>";
}
data.subtext += " " + _time + ", " + _date + "<br>";
}
diff --git a/kicker/applets/clock/zone.cpp b/kicker/applets/clock/zone.cpp
index 48cce1ccb..c81faacc4 100644
--- a/kicker/applets/clock/zone.cpp
+++ b/kicker/applets/clock/zone.cpp
@@ -105,7 +105,7 @@ void Zone::readZoneList(KListView *listView )
if (!comment.isEmpty())
comment = i18n(comment.utf8());
- const TQStringList KontCity = TQStringList::split("/", i18n(tzName.utf8()).tqreplace("_", " "));
+ const TQStringList KontCity = TQStringList::split("/", i18n(tzName.utf8()).replace("_", " "));
TQListViewItem* Kontinent = KontinentMap[KontCity[0]];
if (!Kontinent) {
KontinentMap[KontCity[0]] = new TQListViewItem(listView, KontCity[0]);
@@ -117,7 +117,7 @@ void Zone::readZoneList(KListView *listView )
li->setText(1, comment);
li->setText(2, tzName); /* store complete path in ListView */
- if (_remotezonelist.tqfindIndex(tzName) != -1)
+ if (_remotezonelist.findIndex(tzName) != -1)
li->setOn(true);
// locate the flag from /l10n/%1/flag.png
diff --git a/kicker/applets/launcher/quickaddappsmenu.cpp b/kicker/applets/launcher/quickaddappsmenu.cpp
index 7dcb16098..0eebec315 100644
--- a/kicker/applets/launcher/quickaddappsmenu.cpp
+++ b/kicker/applets/launcher/quickaddappsmenu.cpp
@@ -53,7 +53,7 @@ QuickAddAppsMenu::QuickAddAppsMenu(TQWidget *target, TQWidget *parent, const TQS
void QuickAddAppsMenu::slotExec(int id)
{
- if (!entryMap_.tqcontains(id)) return;
+ if (!entryMap_.contains(id)) return;
KSycocaEntry * e = entryMap_[id];
KService::Ptr service = static_cast<KService *>(e);
emit addAppBefore(locate("apps", service->desktopEntryPath()),_sender);
diff --git a/kicker/applets/launcher/quickbutton.cpp b/kicker/applets/launcher/quickbutton.cpp
index 58f60715d..996d8abe3 100644
--- a/kicker/applets/launcher/quickbutton.cpp
+++ b/kicker/applets/launcher/quickbutton.cpp
@@ -76,7 +76,7 @@ QuickURL::QuickURL(const TQString &u)
if (_menuId.endsWith(".desktop")) {
// Strip path
TQString s = _menuId;
- s = s.mid(s.tqfindRev('/')+1);
+ s = s.mid(s.findRev('/')+1);
s = s.left(s.length()-8);
_service = KService::serviceByStorageId(s);
if (!_service) {
diff --git a/kicker/applets/launcher/quicklauncher.cpp b/kicker/applets/launcher/quicklauncher.cpp
index b5b512d20..7ead9eced 100644
--- a/kicker/applets/launcher/quicklauncher.cpp
+++ b/kicker/applets/launcher/quicklauncher.cpp
@@ -865,7 +865,7 @@ void QuickLauncher::loadConfig()
for (n=0; n<int(m_buttons->size()); ++n)
{
QuickButton* button = (*m_buttons)[n];
- if (volatileButtons.tqcontains(button->menuId()) == false)
+ if (volatileButtons.contains(button->menuId()) == false)
{
button->setSticky(true);
}
diff --git a/kicker/applets/media/mediaapplet.cpp b/kicker/applets/media/mediaapplet.cpp
index d07bfdd2b..8f2d69ab7 100644
--- a/kicker/applets/media/mediaapplet.cpp
+++ b/kicker/applets/media/mediaapplet.cpp
@@ -285,7 +285,7 @@ void MediaApplet::slotNewItems(const KFileItemList &entries)
}
}
- if(!found && !mExcludedList.tqcontains(it.current()->url().url()) )
+ if(!found && !mExcludedList.contains(it.current()->url().url()) )
{
MediumButton *button = new MediumButton(this, *it.current());
button->show();
@@ -336,7 +336,7 @@ void MediaApplet::slotRefreshItems(const KFileItemList &entries)
if(button->fileItem().url()==(*it.current()).url())
{
- if(mExcludedTypesList.tqcontains(mimetype))
+ if(mExcludedTypesList.contains(mimetype))
{
mButtonList.remove(button);
delete button;
@@ -350,7 +350,7 @@ void MediaApplet::slotRefreshItems(const KFileItemList &entries)
}
}
- if(!found && !mExcludedTypesList.tqcontains(mimetype) && !mExcludedList.tqcontains(it.current()->url().url()) )
+ if(!found && !mExcludedTypesList.contains(mimetype) && !mExcludedList.contains(it.current()->url().url()) )
{
MediumButton *button = new MediumButton(this, *it.current());
button->show();
diff --git a/kicker/applets/media/preferencesdialog.cpp b/kicker/applets/media/preferencesdialog.cpp
index 3833f5062..bf8234fe5 100644
--- a/kicker/applets/media/preferencesdialog.cpp
+++ b/kicker/applets/media/preferencesdialog.cpp
@@ -125,7 +125,7 @@ void PreferencesDialog::setExcludedMediumTypes(TQStringList excludedTypesList)
{
if ((*it)->name().startsWith("media/"))
{
- bool ok=excludedTypesList.tqcontains((*it)->name())==0;
+ bool ok=excludedTypesList.contains((*it)->name())==0;
MediumTypeItem *item = new MediumTypeItem(mpMediumTypesListView, (*it)->comment(), (*it)->name());
item->setOn(ok);
}
@@ -156,7 +156,7 @@ void PreferencesDialog::setExcludedMedia(TQStringList excludedList)
{
++it;
- bool ok = excludedList.tqcontains(file->url().url())==0;
+ bool ok = excludedList.contains(file->url().url())==0;
MediumItem *item = new MediumItem(mpMediaListView,
file->text(), *file);
item->setOn(ok);
diff --git a/kicker/applets/minipager/pagerbutton.cpp b/kicker/applets/minipager/pagerbutton.cpp
index 7120fb1f1..d6047d407 100644
--- a/kicker/applets/minipager/pagerbutton.cpp
+++ b/kicker/applets/minipager/pagerbutton.cpp
@@ -157,8 +157,8 @@ bool KMiniPagerButton::shouldPaintWindow( KWin::WindowInfo *info ) const
TQRect r = mapGeometryToViewport(*info);
if (!info->hasState(NET::Sticky) &&
- !TQApplication::desktop()->tqgeometry().tqcontains(r.topLeft()) &&
- !TQApplication::desktop()->tqgeometry().tqcontains(r.topRight()))
+ !TQApplication::desktop()->tqgeometry().contains(r.topLeft()) &&
+ !TQApplication::desktop()->tqgeometry().contains(r.topRight()))
return false;
}
diff --git a/kicker/applets/naughty/NaughtyApplet.cpp b/kicker/applets/naughty/NaughtyApplet.cpp
index 05a64b94b..953bcacbd 100644
--- a/kicker/applets/naughty/NaughtyApplet.cpp
+++ b/kicker/applets/naughty/NaughtyApplet.cpp
@@ -105,7 +105,7 @@ NaughtyApplet::~NaughtyApplet()
void
NaughtyApplet::slotWarn(ulong pid, const TQString & name)
{
- if (ignoreList_.tqcontains(name))
+ if (ignoreList_.contains(name))
return;
TQString s = i18n("A program called '%1' is slowing down the others "
diff --git a/kicker/applets/naughty/NaughtyProcessMonitor.cpp b/kicker/applets/naughty/NaughtyProcessMonitor.cpp
index e8cdaf60f..0a9d5c676 100644
--- a/kicker/applets/naughty/NaughtyProcessMonitor.cpp
+++ b/kicker/applets/naughty/NaughtyProcessMonitor.cpp
@@ -164,7 +164,7 @@ NaughtyProcessMonitor::slotTimeout()
void
NaughtyProcessMonitor::_process(ulong pid, uint load)
{
- if (!d->loadMap_.tqcontains(pid))
+ if (!d->loadMap_.contains(pid))
{
d->loadMap_.insert(pid, load);
return;
@@ -172,12 +172,12 @@ NaughtyProcessMonitor::_process(ulong pid, uint load)
uint oldLoad = d->loadMap_[pid];
bool misbehaving = (load - oldLoad) > 40 * (d->interval_ / 1000);
- bool wasMisbehaving = d->scoreMap_.tqcontains(pid);
+ bool wasMisbehaving = d->scoreMap_.contains(pid);
if (misbehaving)
if (wasMisbehaving)
{
- d->scoreMap_.tqreplace(pid, d->scoreMap_[pid] + 1);
+ d->scoreMap_.replace(pid, d->scoreMap_[pid] + 1);
if (canKill(pid))
emit(runawayProcess(pid, processName(pid)));
}
@@ -187,7 +187,7 @@ NaughtyProcessMonitor::_process(ulong pid, uint load)
if (wasMisbehaving)
d->scoreMap_.remove(pid);
- d->loadMap_.tqreplace(pid, load);
+ d->loadMap_.replace(pid, load);
}
// Here begins the set of system-specific methods.
@@ -221,7 +221,7 @@ NaughtyProcessMonitor::canKill(ulong pid) const
return geteuid() == a;
#elif defined(__OpenBSD__)
// simply check if entry exists in the uid map and use it
- if (!d->uidMap_.tqcontains(pid))
+ if (!d->uidMap_.contains(pid))
return false ;
return geteuid () == d->uidMap_[pid] ;
@@ -289,7 +289,7 @@ NaughtyProcessMonitor::processName(ulong pid) const
TQString processName = parts[0] == "kdeinit:" ? parts[1] : parts[0];
- int lastSlash = processName.tqfindRev('/');
+ int lastSlash = processName.findRev('/');
// Get basename, if there's a path.
if (-1 != lastSlash)
@@ -449,7 +449,7 @@ NaughtyProcessMonitor::getLoad(ulong pid, uint & load) const
return true;
#elif defined(__OpenBSD__)
// use cache
- if (!d->cacheLoadMap_.tqcontains(pid))
+ if (!d->cacheLoadMap_.contains(pid))
return false ;
load = d->cacheLoadMap_[pid] ;
diff --git a/kicker/applets/swallow/swallow.cpp b/kicker/applets/swallow/swallow.cpp
index d5a231363..7112c706a 100644
--- a/kicker/applets/swallow/swallow.cpp
+++ b/kicker/applets/swallow/swallow.cpp
@@ -261,7 +261,7 @@ static void parseCommand(KProcess *proc, TQString cmd)
cmd += " ";
- pos = cmd.tqfind(' ');
+ pos = cmd.find(' ');
*proc << cmd.left(pos);
cmd.remove(0,pos);
cmd = cmd.stripWhiteSpace();
diff --git a/kicker/applets/systemtray/systemtrayapplet.cpp b/kicker/applets/systemtray/systemtrayapplet.cpp
index 6a693fbe8..99aa2d020 100644
--- a/kicker/applets/systemtray/systemtrayapplet.cpp
+++ b/kicker/applets/systemtray/systemtrayapplet.cpp
@@ -260,7 +260,7 @@ void SystemTrayApplet::preferences()
for (; it != itEnd; ++it)
{
TQString name = KWin::windowInfo((*it)->embeddedWinId()).name();
- if(!shownListBox->tqfindItem(name, TQt::ExactMatch | TQt::CaseSensitive))
+ if(!shownListBox->findItem(name, TQt::ExactMatch | TQt::CaseSensitive))
{
shownListBox->insertItem(KWin::icon((*it)->embeddedWinId(), 22, 22, true), name);
}
@@ -271,7 +271,7 @@ void SystemTrayApplet::preferences()
for (; it != itEnd; ++it)
{
TQString name = KWin::windowInfo((*it)->embeddedWinId()).name();
- if(!hiddenListBox->tqfindItem(name, TQt::ExactMatch | TQt::CaseSensitive))
+ if(!hiddenListBox->findItem(name, TQt::ExactMatch | TQt::CaseSensitive))
{
hiddenListBox->insertItem(KWin::icon((*it)->embeddedWinId(), 22, 22, true), name);
}
@@ -322,7 +322,7 @@ void SystemTrayApplet::applySettings()
item;
item = item->next())
{
- if( windowNameToClass.tqcontains(item->text()))
+ if( windowNameToClass.contains(item->text()))
m_sortOrderIconList.append(windowNameToClass[item->text()]);
else
m_sortOrderIconList.append(item->text());
@@ -335,7 +335,7 @@ void SystemTrayApplet::applySettings()
item;
item = item->next())
{
- if( windowNameToClass.tqcontains(item->text()))
+ if( windowNameToClass.contains(item->text()))
m_hiddenIconList.append(windowNameToClass[item->text()]);
else
m_hiddenIconList.append(item->text());
@@ -388,7 +388,7 @@ void SystemTrayApplet::checkAutoRetract()
return;
}
- if (!tqgeometry().tqcontains(mapFromGlobal(TQCursor::pos())))
+ if (!tqgeometry().contains(mapFromGlobal(TQCursor::pos())))
{
m_autoRetractTimer->stop();
if (m_autoRetract)
@@ -590,8 +590,8 @@ bool SystemTrayApplet::isWinManaged(WId w)
bool SystemTrayApplet::shouldHide(WId w)
{
- return m_hiddenIconList.tqfind(KWin::windowInfo(w).name()) != m_hiddenIconList.end()
- || m_hiddenIconList.tqfind('!'+KWin::windowInfo(w,0,NET::WM2WindowClass).windowClassClass())
+ return m_hiddenIconList.find(KWin::windowInfo(w).name()) != m_hiddenIconList.end()
+ || m_hiddenIconList.find('!'+KWin::windowInfo(w,0,NET::WM2WindowClass).windowClassClass())
!= m_hiddenIconList.end();
}
@@ -711,7 +711,7 @@ void SystemTrayApplet::updateTrayWindows()
WId wid = (*emb)->embeddedWinId();
if ((wid == 0) ||
((*emb)->kdeTray() &&
- !kwin_module->systemTrayWindows().tqcontains(wid)))
+ !kwin_module->systemTrayWindows().contains(wid)))
{
(*emb)->deleteLater();
emb = m_shownWins.erase(emb);
@@ -728,7 +728,7 @@ void SystemTrayApplet::updateTrayWindows()
WId wid = (*emb)->embeddedWinId();
if ((wid == 0) ||
((*emb)->kdeTray() &&
- !kwin_module->systemTrayWindows().tqcontains(wid)))
+ !kwin_module->systemTrayWindows().contains(wid)))
{
(*emb)->deleteLater();
emb = m_hiddenWins.erase(emb);
diff --git a/kicker/extensions/dockbar/dockbarextension.cpp b/kicker/extensions/dockbar/dockbarextension.cpp
index c39ac5d4b..aee6a728c 100644
--- a/kicker/extensions/dockbar/dockbarextension.cpp
+++ b/kicker/extensions/dockbar/dockbarextension.cpp
@@ -335,7 +335,7 @@ int DockBarExtension::findContainerAtPoint(const TQPoint& p)
it != containers.constEnd();
++it, ++i)
{
- if ((*it)->tqgeometry().tqcontains(p))
+ if ((*it)->tqgeometry().contains(p))
{
return i;
}
diff --git a/kicker/extensions/kasbar/kasbar.cpp b/kicker/extensions/kasbar/kasbar.cpp
index 482a14db1..3d63c8c4e 100644
--- a/kicker/extensions/kasbar/kasbar.cpp
+++ b/kicker/extensions/kasbar/kasbar.cpp
@@ -670,7 +670,7 @@ KasItem* KasBar::itemAt(const TQPoint &p)
cr.setTopLeft( i->pos() );
cr.setSize( TQSize( itemExtent(), itemExtent() ) );
- if(cr.tqcontains(p))
+ if(cr.contains(p))
return i;
}
diff --git a/kicker/extensions/kasbar/kasbar.h b/kicker/extensions/kasbar/kasbar.h
index 507712cce..201fcc882 100644
--- a/kicker/extensions/kasbar/kasbar.h
+++ b/kicker/extensions/kasbar/kasbar.h
@@ -121,7 +121,7 @@ public:
void clear();
KasItem *take( KasItem *i ) { return items.take( indexOf(i) ); }
KasItem *itemAt( uint i ) { return items.tqat( i ); }
- int indexOf( KasItem *i ) { return items.tqfind( i ); }
+ int indexOf( KasItem *i ) { return items.find( i ); }
KasItemList *itemList() { return &items; }
diff --git a/kicker/extensions/kasbar/kastaskitem.cpp b/kicker/extensions/kasbar/kastaskitem.cpp
index bbc4f6654..cc10b6410 100644
--- a/kicker/extensions/kasbar/kastaskitem.cpp
+++ b/kicker/extensions/kasbar/kastaskitem.cpp
@@ -445,7 +445,7 @@ TQString KasTaskItem::expandMacros( const TQString &format, TQObject *data )
if ( pos >= 0 ) {
TQVariant val = data->property( TQString(re.cap(1)).latin1() );
TQString v = val.asString();
- s.tqreplace( pos, re.matchedLength(), v );
+ s.replace( pos, re.matchedLength(), v );
pos = pos + v.length();
}
}
diff --git a/kicker/kicker/buttons/knewbutton.cpp b/kicker/kicker/buttons/knewbutton.cpp
index b8144d735..2b5153545 100644
--- a/kicker/kicker/buttons/knewbutton.cpp
+++ b/kicker/kicker/buttons/knewbutton.cpp
@@ -215,7 +215,7 @@ bool KNewButton::eventFilter(TQObject *o, TQEvent *e)
e->type() == TQEvent::MouseButtonDblClick )
{
TQMouseEvent *me = TQT_TQMOUSEEVENT(e);
- if (TQT_TQRECT_OBJECT(rect()).tqcontains(mapFromGlobal(me->globalPos())))
+ if (TQT_TQRECT_OBJECT(rect()).contains(mapFromGlobal(me->globalPos())))
{
if (m_pressedDuringPopup && m_popup && m_openTimer != -1
&& (me->button() & Qt::LeftButton) )
@@ -355,9 +355,9 @@ void KNewButton::mouseMoveEvent(TQMouseEvent* e)
{
KButton::mouseMoveEvent(e);
- m_mouseInside = m_sloppyRegion.tqcontains(e->pos());
+ m_mouseInside = m_sloppyRegion.contains(e->pos());
- if ( m_sloppyRegion.tqcontains(e->pos()))
+ if ( m_sloppyRegion.contains(e->pos()))
{
if (m_hoverTimer == -1 && KickerSettings::openOnHover())
m_hoverTimer = startTimer(kMax(200,TQApplication::doubleClickInterval()/2));
diff --git a/kicker/kicker/core/applethandle.cpp b/kicker/kicker/core/applethandle.cpp
index 621038002..382779648 100644
--- a/kicker/kicker/core/applethandle.cpp
+++ b/kicker/kicker/core/applethandle.cpp
@@ -200,7 +200,7 @@ bool AppletHandle::eventFilter(TQObject *o, TQEvent *e)
// a hack for applets that have out-of-process
// elements (e.g the systray) so that the handle
// doesn't flicker when moving over those elements
- if (TQT_TQRECT_OBJECT(w->rect()).tqcontains(w->mapFromGlobal(TQCursor::pos())))
+ if (TQT_TQRECT_OBJECT(w->rect()).contains(w->mapFromGlobal(TQCursor::pos())))
{
nowDrawIt = true;
}
@@ -269,7 +269,7 @@ void AppletHandle::checkHandleHover()
{
if (!m_handleHoverTimer ||
(m_menuButton && m_menuButton->isOn()) ||
- m_applet->tqgeometry().tqcontains(m_applet->mapToParent(
+ m_applet->tqgeometry().contains(m_applet->mapToParent(
m_applet->mapFromGlobal(TQCursor::pos()))))
{
return;
diff --git a/kicker/kicker/core/containerarea.cpp b/kicker/kicker/core/containerarea.cpp
index 412eeec1e..e4e78fd3d 100644
--- a/kicker/kicker/core/containerarea.cpp
+++ b/kicker/kicker/core/containerarea.cpp
@@ -314,7 +314,7 @@ void ContainerArea::loadContainers(const TQStringList& containers)
BaseContainer* a = 0;
- int sep = appletId.tqfindRev('_');
+ int sep = appletId.findRev('_');
Q_ASSERT(sep != -1);
TQString appletType = appletId.left(sep);
@@ -962,7 +962,7 @@ void ContainerArea::mouseMoveEvent(TQMouseEvent *ev)
return;
}
- if (ev->state() == Qt::LeftButton && !TQT_TQRECT_OBJECT(rect()).tqcontains(ev->pos()))
+ if (ev->state() == Qt::LeftButton && !TQT_TQRECT_OBJECT(rect()).contains(ev->pos()))
{
// leaveEvent() doesn't work, while grabbing the mouse
_autoScrollTimer.stop();
@@ -1542,7 +1542,7 @@ TQRect ContainerArea::availableSpaceFollowing(BaseContainer* a)
if (a)
{
- BaseContainer::Iterator it = m_containers.tqfind(a);
+ BaseContainer::Iterator it = m_containers.find(a);
if (it != m_containers.end() &&
++it != m_containers.end())
{
@@ -1784,7 +1784,7 @@ void ContainerArea::updateContainersBackground()
// properly, so just cache the geometry and update background only when
// the geometry changes or when the background really changes (in which
// case the cached is cleared).
- if( !m_cachedGeometry.tqcontains( *it ))
+ if( !m_cachedGeometry.contains( *it ))
{
m_cachedGeometry[ *it ] = TQRect();
connect( *it, TQT_SIGNAL( destroyed()), TQT_SLOT( destroyCachedGeometry()));
diff --git a/kicker/kicker/core/containerarealayout.cpp b/kicker/kicker/core/containerarealayout.cpp
index 4853b8d88..ae4cca873 100644
--- a/kicker/kicker/core/containerarealayout.cpp
+++ b/kicker/kicker/core/containerarealayout.cpp
@@ -350,7 +350,7 @@ void ContainerAreaLayout::insertIntoFreeSpace(TQWidget* widget, TQPoint insertio
if (current)
{
m_items.erase(m_items.fromLast());
- ItemList::iterator insertIt = m_items.tqfind(current);
+ ItemList::iterator insertIt = m_items.find(current);
if (insertIt == m_items.begin())
{
@@ -625,7 +625,7 @@ void ContainerAreaLayout::moveContainerSwitch(TQWidget* container, int distance)
: kMin(newPos, last->leftR() - moving->widthR());
// Move 'moving' to its new position in the container list.
- ItemList::iterator itMoving = m_items.tqfind(moving);
+ ItemList::iterator itMoving = m_items.find(moving);
if (itMoving != m_items.end())
{
diff --git a/kicker/kicker/core/extensionmanager.cpp b/kicker/kicker/core/extensionmanager.cpp
index 7921c636d..03e039ee0 100644
--- a/kicker/kicker/core/extensionmanager.cpp
+++ b/kicker/kicker/core/extensionmanager.cpp
@@ -140,7 +140,7 @@ void ExtensionManager::initialize()
TQString extensionId(*it);
// create a matching applet container
- if (extensionId.tqfind("Extension") == -1)
+ if (extensionId.find("Extension") == -1)
{
continue;
}
@@ -259,7 +259,7 @@ void ExtensionManager::migrateMenubar()
{
TQString extensionId(*it);
- if (extensionId.tqfind("Extension") == -1)
+ if (extensionId.find("Extension") == -1)
{
continue;
}
@@ -291,12 +291,12 @@ void ExtensionManager::migrateMenubar()
}
KConfigGroup group(&extensionConfig, appletId.latin1());
- TQString appletType = appletId.left(appletId.tqfindRev('_'));
+ TQString appletType = appletId.left(appletId.findRev('_'));
if (appletType == "Applet")
{
TQString appletFile = group.readPathEntry("DesktopFile");
- if (appletFile.tqfind("menuapplet.desktop") != -1)
+ if (appletFile.find("menuapplet.desktop") != -1)
{
TQString menubarConfig = locate("config", extension);
KIO::NetAccess::copy(menubarConfig,
diff --git a/kicker/kicker/core/main.cpp b/kicker/kicker/core/main.cpp
index 44d891f1e..76e94a0e3 100644
--- a/kicker/kicker/core/main.cpp
+++ b/kicker/kicker/core/main.cpp
@@ -73,7 +73,7 @@ extern "C" KDE_EXPORT int kdemain( int argc, char ** argv )
XCloseDisplay(dpy);
dpy = 0;
- if ((pos = display_name.tqfindRev('.')) != -1)
+ if ((pos = display_name.findRev('.')) != -1)
display_name.remove(pos, 10);
TQCString env;
diff --git a/kicker/kicker/core/pluginmanager.cpp b/kicker/kicker/core/pluginmanager.cpp
index 86270db62..d1706ada9 100644
--- a/kicker/kicker/core/pluginmanager.cpp
+++ b/kicker/kicker/core/pluginmanager.cpp
@@ -272,7 +272,7 @@ AppletContainer* PluginManager::createAppletContainer(
return 0;
}
- bool untrusted = m_untrustedApplets.tqfind(desktopFile) != m_untrustedApplets.end();
+ bool untrusted = m_untrustedApplets.find(desktopFile) != m_untrustedApplets.end();
if (isStartup && untrusted)
{
// don't load extensions that bombed on us previously!
@@ -325,7 +325,7 @@ ExtensionContainer* PluginManager::createExtensionContainer(const TQString& desk
if (!internal)
{
- bool untrusted = m_untrustedExtensions.tqfind(desktopFile) != m_untrustedExtensions.end();
+ bool untrusted = m_untrustedExtensions.find(desktopFile) != m_untrustedExtensions.end();
if (isStartup && untrusted)
{
// don't load extensions that bombed on us previously!
diff --git a/kicker/kicker/kicker-3.4-reverseLayout.cpp b/kicker/kicker/kicker-3.4-reverseLayout.cpp
index bc3baa9e1..97a35aff6 100644
--- a/kicker/kicker/kicker-3.4-reverseLayout.cpp
+++ b/kicker/kicker/kicker-3.4-reverseLayout.cpp
@@ -88,7 +88,7 @@ int main(int argc, char** argv)
applets[*it].freeSpace = 1 - applets[*it].freeSpace;
// Take care of stretchable applets.
- if (stretchableApplets.tqcontains(applets[*it].desktopFile))
+ if (stretchableApplets.contains(applets[*it].desktopFile))
{
if (it != appletIds.begin())
{
diff --git a/kicker/kicker/plugins/kickoff-beagle-plugin.cpp b/kicker/kicker/plugins/kickoff-beagle-plugin.cpp
index a506bcd5d..3cad77ca4 100644
--- a/kicker/kicker/plugins/kickoff-beagle-plugin.cpp
+++ b/kicker/kicker/plugins/kickoff-beagle-plugin.cpp
@@ -315,7 +315,7 @@ HitMenuItem *KickoffBeaglePlugin::hitToHitMenuItem (int category, Hit *hit)
case WEBHIST:
uri = hit->getUri ();
title = (*hit) [dc_title];
- title = title.tqreplace(TQRegExp("\n")," ");
+ title = title.replace(TQRegExp("\n")," ");
mimetype = "text/html";
if (title.isEmpty () || title.stripWhiteSpace ().isEmpty ()) {
title = uri.prettyURL ();
@@ -375,15 +375,15 @@ HitMenuItem *KickoffBeaglePlugin::hitToHitMenuItem (int category, Hit *hit)
TQString command = desktopfile.readEntry("Exec");
if (command==input)
score = 100;
- else if (command.tqfind(input)==0)
+ else if (command.find(input)==0)
score = 50;
- else if (command.tqfind(input)!=-1)
+ else if (command.find(input)!=-1)
score = 10;
else if (title==input)
score = 100;
- else if (title.tqfind(input)==0)
+ else if (title.find(input)==0)
score = 50;
- else if (title.tqfind(input)!=-1)
+ else if (title.find(input)!=-1)
score = 10;
break;
}
diff --git a/kicker/kicker/ui/addapplet.cpp b/kicker/kicker/ui/addapplet.cpp
index 47a2c5835..163a4ae9d 100644
--- a/kicker/kicker/ui/addapplet.cpp
+++ b/kicker/kicker/ui/addapplet.cpp
@@ -435,7 +435,7 @@ void AddAppletDialog::addApplet(AppletWidget* applet)
// reset the odd/even colouring from this item on down in the list
bool odd = applet->odd();
- AppletWidget::List::const_iterator it = m_appletWidgetList.tqfind(applet);
+ AppletWidget::List::const_iterator it = m_appletWidgetList.find(applet);
for (; it != m_appletWidgetList.constEnd(); ++it)
{
if ((*it)->isHidden())
@@ -484,8 +484,8 @@ bool AddAppletDialog::appletMatchesSearch(const AppletWidget* w,
return (m_selectedType == AppletInfo::Undefined ||
w->info().type() & m_selectedType) &&
- (w->info().name().tqcontains(s, false) ||
- w->info().comment().tqcontains(s, false));
+ (w->info().name().contains(s, false) ||
+ w->info().comment().contains(s, false));
}
void AddAppletDialog::delayedSearch()
diff --git a/kicker/kicker/ui/addapplet_mnu.cpp b/kicker/kicker/ui/addapplet_mnu.cpp
index 19bbf0f11..6d5c4482f 100644
--- a/kicker/kicker/ui/addapplet_mnu.cpp
+++ b/kicker/kicker/ui/addapplet_mnu.cpp
@@ -54,11 +54,11 @@ void PanelAddAppletMenu::slotAboutToShow()
if (ai.icon().isEmpty() || ai.icon() == "unknown")
{
- insertItem(ai.name().tqreplace( "&", "&&" ), i);
+ insertItem(ai.name().replace( "&", "&&" ), i);
}
else
{
- insertItem(SmallIconSet(ai.icon()), ai.name().tqreplace( "&", "&&" ), i);
+ insertItem(SmallIconSet(ai.icon()), ai.name().replace( "&", "&&" ), i);
}
if (ai.isUniqueApplet() && PluginManager::the()->hasInstance(ai))
diff --git a/kicker/kicker/ui/addbutton_mnu.cpp b/kicker/kicker/ui/addbutton_mnu.cpp
index c04a832e6..02c4718d4 100644
--- a/kicker/kicker/ui/addbutton_mnu.cpp
+++ b/kicker/kicker/ui/addbutton_mnu.cpp
@@ -46,7 +46,7 @@ PanelAddButtonMenu::PanelAddButtonMenu(ContainerArea* cArea, TQWidget * parent,
void PanelAddButtonMenu::slotExec(int id)
{
- if (!entryMap_.tqcontains(id))
+ if (!entryMap_.contains(id))
return;
KSycocaEntry * e = entryMap_[id];
diff --git a/kicker/kicker/ui/addextension_mnu.cpp b/kicker/kicker/ui/addextension_mnu.cpp
index 325897a8c..b22187443 100644
--- a/kicker/kicker/ui/addextension_mnu.cpp
+++ b/kicker/kicker/ui/addextension_mnu.cpp
@@ -44,7 +44,7 @@ void PanelAddExtensionMenu::slotAboutToShow()
AppletInfo::List::const_iterator it = extensions.constBegin();
for( int i = 0; it != extensions.constEnd(); ++it, ++i ) {
const AppletInfo& ai = (*it);
- insertItem( ai.name().tqreplace( "&", "&&" ), i );
+ insertItem( ai.name().replace( "&", "&&" ), i );
if ( ai.isUniqueApplet() && PluginManager::the()->hasInstance(ai) ) {
setItemEnabled( i, false );
setItemChecked( i, true );
diff --git a/kicker/kicker/ui/appletop_mnu.cpp b/kicker/kicker/ui/appletop_mnu.cpp
index 2bd8f7bd0..fb4f97ea8 100644
--- a/kicker/kicker/ui/appletop_mnu.cpp
+++ b/kicker/kicker/ui/appletop_mnu.cpp
@@ -41,7 +41,7 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, TQPopupMenu *opMenu, const TQP
bool isButton = (parent && parent->inherits("ButtonContainer"));
bool isMenu = false;
TQString titleText = title;
- titleText = titleText.tqreplace('&', "&&");
+ titleText = titleText.replace('&', "&&");
if (isButton)
{
isMenu = static_cast<ButtonContainer*>(parent)->isAMenu();
diff --git a/kicker/kicker/ui/browser_mnu.cpp b/kicker/kicker/ui/browser_mnu.cpp
index 46f79db2b..ee62791e9 100644
--- a/kicker/kicker/ui/browser_mnu.cpp
+++ b/kicker/kicker/ui/browser_mnu.cpp
@@ -244,7 +244,7 @@ void PanelBrowserMenu::initialize()
title = c.readEntry("Name", title);
TQString s = c.readEntry("Icon");
- if(!_icons->tqcontains(s)) {
+ if(!_icons->contains(s)) {
icon = KGlobal::iconLoader()->loadIcon(s, KIcon::Small, KIcon::SizeSmall,
KIcon::DefaultState, 0, true);
@@ -344,7 +344,7 @@ void PanelBrowserMenu::append(const TQPixmap &pixmap, const TQString &title, con
// avoid &'s being converted to accelerators
TQString newTitle = title;
newTitle = KStringHandler::cEmSqueeze( newTitle, fontMetrics(), 20 );
- newTitle.tqreplace("&", "&&");
+ newTitle.replace("&", "&&");
// insert menu item
int id = insertItem(pixmap, newTitle);
@@ -362,7 +362,7 @@ void PanelBrowserMenu::append(const TQPixmap &pixmap, const TQString &title, Pan
// avoid &'s being converted to accelerators
TQString newTitle = title;
newTitle = KStringHandler::cEmSqueeze( newTitle, fontMetrics(), 20 );
- newTitle.tqreplace("&", "&&");
+ newTitle.replace("&", "&&");
// insert submenu
insertItem(pixmap, newTitle, subMenu);
@@ -388,7 +388,7 @@ void PanelBrowserMenu::mouseMoveEvent(TQMouseEvent *e)
// get id
int id = idAt(_lastpress);
- if(!_filemap.tqcontains(id)) return;
+ if(!_filemap.contains(id)) return;
// reset _lastpress
_lastpress = TQPoint(-1, -1);
@@ -439,7 +439,7 @@ void PanelBrowserMenu::slotExec(int id)
{
kapp->propagateSessionManager();
- if(!_filemap.tqcontains(id)) return;
+ if(!_filemap.contains(id)) return;
KURL url;
url.setPath(path() + "/" + _filemap[id]);
@@ -494,9 +494,9 @@ void PanelBrowserMenu::slotMimeCheck()
// kdDebug() << url.url() << ": " << icon << endl;
file = KStringHandler::cEmSqueeze( file, fontMetrics(), 20 );
- file.tqreplace("&", "&&");
+ file.replace("&", "&&");
- if(!_icons->tqcontains(icon)) {
+ if(!_icons->contains(icon)) {
TQPixmap pm = SmallIcon(icon);
if( pm.height() > 16 )
{
diff --git a/kicker/kicker/ui/exe_dlg.cpp b/kicker/kicker/ui/exe_dlg.cpp
index 0829f6ccb..d39fb5942 100644
--- a/kicker/kicker/ui/exe_dlg.cpp
+++ b/kicker/kicker/ui/exe_dlg.cpp
@@ -164,7 +164,7 @@ void PanelExeDialog::slotTextChanged(const TQString &str)
}
TQString exeLocation = str;
- TQMap<TQString, TQString>::iterator it = m_partialPath2full.tqfind(str);
+ TQMap<TQString, TQString>::iterator it = m_partialPath2full.find(str);
if (it != m_partialPath2full.end())
exeLocation = it.data();
@@ -174,7 +174,7 @@ void PanelExeDialog::slotTextChanged(const TQString &str)
void PanelExeDialog::slotReturnPressed()
{
- if (m_partialPath2full.tqcontains(ui->m_exec->url()))
+ if (m_partialPath2full.contains(ui->m_exec->url()))
ui->m_exec->setURL(m_partialPath2full[ui->m_exec->url()]);
}
diff --git a/kicker/kicker/ui/itemview.cpp b/kicker/kicker/ui/itemview.cpp
index f86ae537a..3a2978261 100644
--- a/kicker/kicker/ui/itemview.cpp
+++ b/kicker/kicker/ui/itemview.cpp
@@ -385,7 +385,7 @@ void KMenuItemSeparator::setLink( const TQString &text, const TQString &url )
bool KMenuItemSeparator::hitsLink( const TQPoint &pos )
{
- return m_link_rect.tqcontains( pos );
+ return m_link_rect.contains( pos );
}
void KMenuItemSeparator::preparePixmap( int width )
@@ -1162,7 +1162,7 @@ bool KMenuItemDrag::decode(const TQMimeSource* e, KMenuItemInfo& item)
item.m_title = item.m_path;
item.m_icon = KMimeType::iconForURL( url );
item.m_title = item.m_path.section( '/', -1, -1 );
- int last_slash = url.tqfindRev ('/', -1);
+ int last_slash = url.findRev ('/', -1);
if (last_slash == 0)
item.m_description = i18n("Directory: /)");
else
@@ -1205,7 +1205,7 @@ bool FavoritesItemView::acceptDrag (TQDropEvent* event) const
TQStringList favs = KickerSettings::favorites();
if (item.m_s)
- return favs.tqfind(item.m_s->storageId())==favs.end();
+ return favs.find(item.m_s->storageId())==favs.end();
else {
TQStringList::Iterator it;
@@ -1219,7 +1219,7 @@ bool FavoritesItemView::acceptDrag (TQDropEvent* event) const
for (it = favs.begin(); it != favs.end(); ++it) {
if ((*it)[0]=='/') {
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==uri)
+ if (df.readURL().replace("file://",TQString())==uri)
break;
}
}
@@ -1233,15 +1233,15 @@ bool FavoritesItemView::acceptDrag (TQDropEvent* event) const
TQStringList favs = KickerSettings::favorites();
if (text.endsWith(".desktop")) {
- KService::Ptr p = KService::serviceByDesktopPath(text.tqreplace("file://",TQString()));
- return (p && favs.tqfind(p->storageId())==favs.end());
+ KService::Ptr p = KService::serviceByDesktopPath(text.replace("file://",TQString()));
+ return (p && favs.find(p->storageId())==favs.end());
}
else {
TQStringList::Iterator it;
for (it = favs.begin(); it != favs.end(); ++it) {
if ((*it)[0]=='/') {
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==text)
+ if (df.readURL().replace("file://",TQString())==text)
break;
}
}
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index 110cd15f0..65011890e 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -652,7 +652,7 @@ TQMouseEvent PanelKMenu::translateMouseEvent( TQMouseEvent* e )
{
TQRect side = sideImageRect();
- if ( !side.tqcontains( e->pos() ) )
+ if ( !side.contains( e->pos() ) )
return *e;
TQPoint newpos( e->pos() );
diff --git a/kicker/kicker/ui/k_new_mnu.cpp b/kicker/kicker/ui/k_new_mnu.cpp
index 542e08be9..1a87b163d 100644
--- a/kicker/kicker/ui/k_new_mnu.cpp
+++ b/kicker/kicker/ui/k_new_mnu.cpp
@@ -141,12 +141,12 @@ static TQString workaroundStringFreeze(const TQString& str)
{
TQString s = str;
- s.tqreplace("<u>","&");
+ s.replace("<u>","&");
TQRegExp re("<[^>]+>");
re.setMinimal(true);
re.setCaseSensitive(false);
- s.tqreplace(re, "");
+ s.replace(re, "");
s = s.simplifyWhiteSpace();
return s;
@@ -517,7 +517,7 @@ bool KMenu::eventFilter ( TQObject * receiver, TQEvent* e)
return false;
}
- if (m_sloppyRegion.tqcontains(p)) {
+ if (m_sloppyRegion.contains(p)) {
if (e->type() == TQEvent::MouseButtonPress /*&& m_sloppyTimer.isActive()*/)
m_sloppySourceClicked = true;
@@ -682,9 +682,9 @@ bool KMenu::eventFilter ( TQObject * receiver, TQEvent* e)
void KMenu::slotSloppyTimeout()
{
- if (m_sloppyRegion.tqcontains(TQCursor::pos()) && !m_sloppySource.isNull())
+ if (m_sloppyRegion.contains(TQCursor::pos()) && !m_sloppySource.isNull())
{
- if ( m_sloppySource.tqcontains(TQCursor::pos()))
+ if ( m_sloppySource.contains(TQCursor::pos()))
{
m_stacker->raiseWidget(m_sloppyWidget);
@@ -882,7 +882,7 @@ void KMenu::slotGoExitSubMenu(const TQString& url)
m_exitView->rightView()->insertItem( "switchuser", i18n( "Start New Session" ),
i18n( "Start a parallel session" ), "kicker:/switchuser", nId++, index++ );
- m_exitView->rightView()->insertItem( "lock", i18n( "Lock Current && Start New Session").tqreplace("&&","&"),
+ m_exitView->rightView()->insertItem( "lock", i18n( "Lock Current && Start New Session").replace("&&","&"),
i18n( "Lock screen and start a parallel session" ), "kicker:/switchuserafterlock", nId++, index++ );
SessList sess;
@@ -918,7 +918,7 @@ void KMenu::goSubMenu(const TQString& relPath, bool keyboard)
int index = rel.length() - 1;
if ( rel.endsWith( "/" ) )
index--;
- index = rel.tqfindRev( '/', index );
+ index = rel.findRev( '/', index );
kdDebug() << "goup, rel '" << rel << "' " << index << endl;
TQString currel = rel;
rel = rel.left( index + 1 );
@@ -1165,7 +1165,7 @@ void KMenu::fillMenu(KServiceGroup::Ptr&
KService::Ptr s(static_cast<KService *>(e));
if (_relPath.isEmpty()) {
TQStringList favs = KickerSettings::favorites();
- if (favs.tqfind(s->storageId())!=favs.end())
+ if (favs.find(s->storageId())!=favs.end())
continue;
}
#ifdef KDELIBS_SUSE
@@ -1259,7 +1259,7 @@ void KMenu::initialize()
if ((*it)[0]=='/') {
KDesktopFile df((*it),true);
TQString url = df.readURL();
- if (!KURL(url).isLocalFile() || TQFile::exists(url.tqreplace("file://",TQString())))
+ if (!KURL(url).isLocalFile() || TQFile::exists(url.replace("file://",TQString())))
m_favoriteView->insertItem(df.readIcon(),df.readName(),df.readGenericName(), url, nId++, index++);
}
else {
@@ -1314,7 +1314,7 @@ void KMenu::insertStaticExitItems()
m_exitView->leftView()->insertItem( "exit", i18n( "Shutdown Computer" ),
i18n( "Turn off computer" ), "kicker:/shutdown", nId++, index++ );
- m_exitView->leftView()->insertItem( "reload", i18n( "&Restart Computer" ).tqreplace("&",""),
+ m_exitView->leftView()->insertItem( "reload", i18n( "&Restart Computer" ).replace("&",""),
i18n( "Restart and boot the default system" ),
"kicker:/restart", nId++, index++ );
@@ -1906,7 +1906,7 @@ bool KMenu::dontQueryNow (const TQString& str)
if (str == current_query.get())
return true;
int length = str.length ();
- int last_whitespace = str.tqfindRev (' ', -1);
+ int last_whitespace = str.findRev (' ', -1);
if (last_whitespace == length-1)
return false; // if the user typed a space, search
if (last_whitespace >= length-2)
@@ -1964,7 +1964,7 @@ void KMenu::createNewProgramList(TQString relPath)
} else if(e->isType(KST_KService)) {
KService::Ptr s(static_cast<KService *>(e));
if(s->type() == "Application" && !s->noDisplay() ) {
- TQString shortStorageId = s->storageId().tqreplace(".desktop",TQString());
+ TQString shortStorageId = s->storageId().replace(".desktop",TQString());
TQStringList::Iterator it_find = m_seenPrograms.begin();
TQStringList::Iterator it_end = m_seenPrograms.end();
bool found = false;
@@ -1979,7 +1979,7 @@ void KMenu::createNewProgramList(TQString relPath)
m_seenProgramsChanged=true;
m_seenPrograms+=shortStorageId;
m_seenPrograms+=m_tqcurrentDate;
- if (m_newInstalledPrograms.tqfind(s->storageId())==m_newInstalledPrograms.end())
+ if (m_newInstalledPrograms.find(s->storageId())==m_newInstalledPrograms.end())
m_newInstalledPrograms+=s->storageId();
}
else {
@@ -1987,7 +1987,7 @@ void KMenu::createNewProgramList(TQString relPath)
if (*(it_find)!="-") {
TQDate date = TQDate::fromString(*(it_find),Qt::ISODate);
if (date.daysTo(TQDate::currentDate())<3) {
- if (m_newInstalledPrograms.tqfind(s->storageId())==m_newInstalledPrograms.end())
+ if (m_newInstalledPrograms.find(s->storageId())==m_newInstalledPrograms.end())
m_newInstalledPrograms+=s->storageId();
}
else {
@@ -2033,24 +2033,24 @@ void KMenu::searchProgramList(TQString relPath)
int score = 0;
if (s->exec()==input)
score = 100;
- else if (s->exec().tqfind(input)==0)
+ else if (s->exec().find(input)==0)
score = 50;
- else if (s->exec().tqfind(input)!=-1)
+ else if (s->exec().find(input)!=-1)
score = 10;
else if (s->name().lower()==input)
score = 100;
else if (s->genericName().lower()==input)
score = 100;
- else if (s->name().lower().tqfind(input)==0)
+ else if (s->name().lower().find(input)==0)
score = 50;
- else if (s->genericName().lower().tqfind(input)==0)
+ else if (s->genericName().lower().find(input)==0)
score = 50;
- else if (s->name().lower().tqfind(input)!=-1)
+ else if (s->name().lower().find(input)!=-1)
score = 10;
- else if (s->genericName().lower().tqfind(input)!=-1)
+ else if (s->genericName().lower().find(input)!=-1)
score = 10;
- if (s->exec().tqfind(' ')==-1)
+ if (s->exec().find(' ')==-1)
score+=1;
if (s->substituteUid())
@@ -2082,7 +2082,7 @@ void KMenu::searchProgramList(TQString relPath)
insertSearchResult(hit_item);
TQString exe = s->exec();
- int pos = exe.tqfind(' ');
+ int pos = exe.find(' ');
if (pos>0)
exe=exe.left(pos);
m_programsInMenu+=KGlobal::dirs()->findExe(exe);
@@ -2329,13 +2329,13 @@ void KMenu::doQuery (bool return_pressed)
if (exe.endsWith("/bin/gimp")) {
TQStringList::ConstIterator it = m_programsInMenu.begin();
for (; it != m_programsInMenu.end(); ++it)
- if ((*it).tqfind("bin/gimp-remote-")!=-1) {
+ if ((*it).find("bin/gimp-remote-")!=-1) {
gimp_hack = true;
break;
}
}
#endif
- if (m_programsInMenu.tqfind(exe)!=m_programsInMenu.end()
+ if (m_programsInMenu.find(exe)!=m_programsInMenu.end()
#ifdef KDELIBS_SUSE
|| gimp_hack
#endif
@@ -2540,7 +2540,7 @@ TQString KMenu::iconForHitMenuItem(HitMenuItem *hit_item)
return favicon;
}
- if (mimetype_iconstore.tqcontains (hit_item->mimetype))
+ if (mimetype_iconstore.contains (hit_item->mimetype))
return (mimetype_iconstore [hit_item->mimetype]);
else {
KMimeType::Ptr mimetype_ptr = KMimeType::mimeType (hit_item->mimetype);
@@ -2770,7 +2770,7 @@ void KMenu::slotContextMenuRequested( TQListViewItem * item, const TQPoint & pos
i18n("Add to Favorites"), AddToFavorites);
TQStringList favs = KickerSettings::favorites();
- if (m_popupService && favs.tqfind(m_popupService->storageId())!=favs.end())
+ if (m_popupService && favs.find(m_popupService->storageId())!=favs.end())
m_popupMenu->setItemEnabled(num, false);
else {
TQStringList::Iterator it;
@@ -2779,7 +2779,7 @@ void KMenu::slotContextMenuRequested( TQListViewItem * item, const TQPoint & pos
if ((*it)[0]=='/')
{
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==m_popupPath.path)
+ if (df.readURL().replace("file://",TQString())==m_popupPath.path)
break;
}
}
@@ -2971,7 +2971,7 @@ void KMenu::slotContextMenu(int selected)
case AddToFavorites:
if (m_popupService) {
- if (favs.tqfind(m_popupService->storageId())==favs.end()) {
+ if (favs.find(m_popupService->storageId())==favs.end()) {
KService::Ptr p = KService::serviceByStorageId(m_popupService->storageId());
m_favoriteView->insertMenuItem(p, serviceMenuEndId()+favs.count()+1);
favs+=m_popupService->storageId();
@@ -2982,7 +2982,7 @@ void KMenu::slotContextMenu(int selected)
for (it = favs.begin(); it != favs.end(); ++it) {
if ((*it)[0]=='/') {
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==m_popupPath.path)
+ if (df.readURL().replace("file://",TQString())==m_popupPath.path)
break;
}
}
@@ -3010,7 +3010,7 @@ void KMenu::slotContextMenu(int selected)
case RemoveFromFavorites:
if (m_popupService) {
- favs.erase(favs.tqfind(m_popupService->storageId()));
+ favs.erase(favs.find(m_popupService->storageId()));
for (TQListViewItemIterator it(m_favoriteView); it.current(); ++it) {
KMenuItem* kitem = static_cast<KMenuItem*>(it.current());
@@ -3024,7 +3024,7 @@ void KMenu::slotContextMenu(int selected)
for (TQStringList::Iterator it = favs.begin(); it != favs.end(); ++it) {
if ((*it)[0]=='/') {
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==m_popupPath.path) {
+ if (df.readURL().replace("file://",TQString())==m_popupPath.path) {
TQFile::remove((*it));
favs.erase(it);
break;
@@ -3277,7 +3277,7 @@ void KMenu::searchActionClicked(TQListViewItem* item)
if( !KURIFilter::self()->filterURI(data, list) ) {
KDesktopFile file("searchproviders/google.desktop", true, "services");
- data.setData(file.readEntry("Query").tqreplace("\\{@}", m_kcommand->currentText()));
+ data.setData(file.readEntry("Query").replace("\\{@}", m_kcommand->currentText()));
}
(void) new KRun( data.uri(), parentWidget());
@@ -3320,7 +3320,7 @@ void KMenu::updateRecentlyUsedApps(KService::Ptr &service)
TQString strItem(service->desktopEntryPath());
// don't add an item from root kmenu level
- if (!strItem.tqcontains('/'))
+ if (!strItem.contains('/'))
{
return;
}
@@ -3377,7 +3377,7 @@ void KMenu::slotFavoritesMoved( TQListViewItem* item, TQListViewItem* /*afterFir
// remove at old position
if (kitem->service())
{
- favs.erase(favs.tqfind(kitem->service()->storageId()));
+ favs.erase(favs.find(kitem->service()->storageId()));
addFav = kitem->service()->storageId();
}
else
@@ -3387,7 +3387,7 @@ void KMenu::slotFavoritesMoved( TQListViewItem* item, TQListViewItem* /*afterFir
if ((*it)[0]=='/')
{
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==kitem->path())
+ if (df.readURL().replace("file://",TQString())==kitem->path())
{
addFav = *it;
favs.erase(it);
@@ -3412,7 +3412,7 @@ void KMenu::slotFavoritesMoved( TQListViewItem* item, TQListViewItem* /*afterFir
if ((*it)[0]=='/' && !kafterNow->service())
{
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==kafterNow->path())
+ if (df.readURL().replace("file://",TQString())==kafterNow->path())
{
kdDebug() << "insert after " << kafterNow->path() << endl;
favs.insert(++it,addFav);
@@ -3549,7 +3549,7 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
if (item.m_s)
{
- if (favs.tqfind(item.m_s->storageId())==favs.end())
+ if (favs.find(item.m_s->storageId())==favs.end())
{
newItem = m_favoriteView->insertMenuItem(item.m_s, serviceMenuEndId()+favs.count()+1);
favs += item.m_s->storageId();
@@ -3569,7 +3569,7 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
if ((*it)[0]=='/')
{
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==uri)
+ if (df.readURL().replace("file://",TQString())==uri)
break;
}
}
@@ -3597,8 +3597,8 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
if (text.endsWith(".desktop"))
{
- KService::Ptr p = KService::serviceByDesktopPath(text.tqreplace("file://",TQString()));
- if (p && favs.tqfind(p->storageId())==favs.end()) {
+ KService::Ptr p = KService::serviceByDesktopPath(text.replace("file://",TQString()));
+ if (p && favs.find(p->storageId())==favs.end()) {
newItem = m_favoriteView->insertMenuItem(p, serviceMenuEndId()+favs.count()+1);
favs+=p->storageId();
}
@@ -3611,7 +3611,7 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
if ((*it)[0]=='/')
{
KDesktopFile df((*it),true);
- if (df.readURL().tqreplace("file://",TQString())==text)
+ if (df.readURL().replace("file://",TQString())==text)
break;
}
}
diff --git a/kicker/kicker/ui/kickoff_bar.cpp b/kicker/kicker/ui/kickoff_bar.cpp
index 6be19459c..6a41a719b 100644
--- a/kicker/kicker/ui/kickoff_bar.cpp
+++ b/kicker/kicker/ui/kickoff_bar.cpp
@@ -56,7 +56,7 @@ void KickoffTabBar::paint(TQPainter* p, TQTab* t, bool selected) const
// else if(t == d->pressed)
// flags |= TQStyle::Style_Sunken;
//selection flags
- if(t->rect().tqcontains(mapFromGlobal(TQCursor::pos())))
+ if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
tqstyle().tqdrawControl( TQStyle::CE_TabBarTab, p, this, t->rect(),
tqcolorGroup(), flags, TQStyleOption(t) );
@@ -114,7 +114,7 @@ void KickoffTabBar::paintLabel(TQPainter* p, const TQRect& br, TQTab* t, bool ha
flags |= TQStyle::Style_Selected;
// else if(t == d->pressed)
// flags |= TQStyle::Style_Sunken;
- if(t->rect().tqcontains(mapFromGlobal(TQCursor::pos())))
+ if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
tqstyle().tqdrawControl( TQStyle::CE_TabBarLabel, p, this, rt,
t->isEnabled() ? tqcolorGroup(): tqpalette().disabled(),
diff --git a/kicker/kicker/ui/query.cpp b/kicker/kicker/ui/query.cpp
index 0bcff59c1..12b9b6910 100644
--- a/kicker/kicker/ui/query.cpp
+++ b/kicker/kicker/ui/query.cpp
@@ -111,7 +111,7 @@ bool Query::matches(const TQString &term)
bool next_alternative = false;
for ( TQStringList::ConstIterator it = alt->excludes.begin(); it != alt->excludes.end(); ++it ) {
- if ( lower_term.tqfind(*it)!=-1 ) {
+ if ( lower_term.find(*it)!=-1 ) {
next_alternative = true;
continue;
}
@@ -120,7 +120,7 @@ bool Query::matches(const TQString &term)
continue;
for ( TQStringList::ConstIterator it = alt->includes.begin(); it != alt->includes.end(); ++it ) {
- if ( lower_term.tqfind(*it)==-1 ) {
+ if ( lower_term.find(*it)==-1 ) {
next_alternative = true;
continue;
}
diff --git a/kicker/kicker/ui/removeapplet_mnu.cpp b/kicker/kicker/ui/removeapplet_mnu.cpp
index 295651523..8dfaa00d2 100644
--- a/kicker/kicker/ui/removeapplet_mnu.cpp
+++ b/kicker/kicker/ui/removeapplet_mnu.cpp
@@ -63,7 +63,7 @@ void PanelRemoveAppletMenu::slotAboutToShow()
}
items.append(PanelMenuItemInfo(container->icon(),
- container->visibleName().tqreplace("&", "&&"),
+ container->visibleName().replace("&", "&&"),
id));
++id;
++it;
diff --git a/kicker/kicker/ui/removeextension_mnu.cpp b/kicker/kicker/ui/removeextension_mnu.cpp
index c28ae1162..9a1655bae 100644
--- a/kicker/kicker/ui/removeextension_mnu.cpp
+++ b/kicker/kicker/ui/removeextension_mnu.cpp
@@ -57,7 +57,7 @@ void PanelRemoveExtensionMenu::slotAboutToShow()
for (ExtensionList::iterator it = m_containers.begin(); it != itEnd; ++it)
{
const AppletInfo info = (*it)->info();
- TQString name = info.name().tqreplace("&", "&&");
+ TQString name = info.name().replace("&", "&&");
switch ((*it)->position())
{
case KPanelExtension::Top:
diff --git a/kicker/kicker/ui/service_mnu.cpp b/kicker/kicker/ui/service_mnu.cpp
index 9c4d09929..ee0414644 100644
--- a/kicker/kicker/ui/service_mnu.cpp
+++ b/kicker/kicker/ui/service_mnu.cpp
@@ -231,7 +231,7 @@ void PanelServiceMenu::fillMenu(KServiceGroup::Ptr& _root,
TQString inlineHeaderName = g->showInlineHeader() ? groupCaption : "";
// Item names may contain ampersands. To avoid them being converted
// to accelerators, replace them with two ampersands.
- groupCaption.tqreplace("&", "&&");
+ groupCaption.replace("&", "&&");
if ( nbChildCount == 1 && g->allowInline() && g->inlineAlias())
{
@@ -411,10 +411,10 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
{
if ((!suppressGenericNames ||
- !suppressGenericNames->tqcontains(s->untranslatedGenericName())) &&
- serviceName.tqfind(comment, 0, true) == -1)
+ !suppressGenericNames->contains(s->untranslatedGenericName())) &&
+ serviceName.find(comment, 0, true) == -1)
{
- if (comment.tqfind(serviceName, 0, true) == -1)
+ if (comment.find(serviceName, 0, true) == -1)
{
serviceName = i18n("Entries in K-menu: %1 app name, %2 description", "%1 - %2").arg(serviceName, comment);
}
@@ -450,7 +450,7 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
// item names may contain ampersands. To avoid them being converted
// to accelerators, replace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ serviceName.replace("&", "&&");
TQString icon = s->icon();
if (icon=="unknown")
@@ -544,7 +544,7 @@ bool PanelServiceMenu::highlightMenuItem( const TQString &menuItemId )
void PanelServiceMenu::slotExec(int id)
{
- if (!entryMap_.tqcontains(id))
+ if (!entryMap_.contains(id))
{
return;
}
@@ -578,7 +578,7 @@ void PanelServiceMenu::mouseReleaseEvent(TQMouseEvent * ev)
return;
}
- if (!entryMap_.tqcontains(id))
+ if (!entryMap_.contains(id))
{
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
@@ -769,7 +769,7 @@ void PanelServiceMenu::mouseMoveEvent(TQMouseEvent * ev)
if (id < serviceMenuStartId())
return;
- if (!entryMap_.tqcontains(id)) {
+ if (!entryMap_.contains(id)) {
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
}
@@ -838,7 +838,7 @@ void PanelServiceMenu::dragEnterEvent(TQDragEnterEvent *event)
void PanelServiceMenu::dragLeaveEvent(TQDragLeaveEvent *)
{
// see PanelServiceMenu::dragEnterEvent why this is nescessary
- if (!TQT_TQRECT_OBJECT(frameGeometry()).tqcontains(TQCursor::pos()))
+ if (!TQT_TQRECT_OBJECT(frameGeometry()).contains(TQCursor::pos()))
{
KURLDrag::setTarget(0);
}
@@ -932,12 +932,12 @@ void PanelServiceMenu::setSearchString(const TQString &searchString)
int id = *menuItemIt;
KService* s = dynamic_cast< KService* >( static_cast< KSycocaEntry* >( entryMap_[ id ]));
TQString menuText = text(id);
- if (menuText.tqcontains(searchString, false) > 0
- || ( s != NULL && ( s->name().tqcontains(searchString, false) > 0
- || s->exec().tqcontains(searchString, false) > 0
- || s->comment().tqcontains(searchString, false) > 0
- || s->genericName().tqcontains(searchString, false) > 0
- || s->exec().tqcontains(searchString, false) > 0 )
+ if (menuText.contains(searchString, false) > 0
+ || ( s != NULL && ( s->name().contains(searchString, false) > 0
+ || s->exec().contains(searchString, false) > 0
+ || s->comment().contains(searchString, false) > 0
+ || s->genericName().contains(searchString, false) > 0
+ || s->exec().contains(searchString, false) > 0 )
)) {
setItemEnabled(id, true);
foundSomething = true;
@@ -951,7 +951,7 @@ void PanelServiceMenu::setSearchString(const TQString &searchString)
/*for (int i=count()-1; i>=0; --i) {
int id = idAt(i);
TQString menuText = text(id);
- if (menuText.tqcontains(searchString, false) > 0) {
+ if (menuText.contains(searchString, false) > 0) {
setItemEnabled(id, true);
foundSomething = true;
nonemptyMenus.insert(id);
@@ -995,7 +995,7 @@ void PanelServiceMenu::updateRecentlyUsedApps(KService::Ptr &service)
TQString strItem(service->desktopEntryPath());
// don't add an item from root kmenu level
- if (!strItem.tqcontains('/'))
+ if (!strItem.contains('/'))
{
return;
}
diff --git a/kicker/libkicker/global.cpp b/kicker/libkicker/global.cpp
index 67f280106..3265c428c 100644
--- a/kicker/libkicker/global.cpp
+++ b/kicker/libkicker/global.cpp
@@ -207,7 +207,7 @@ TQPopupMenu* reduceMenu(TQPopupMenu *menu)
return menu;
}
- TQMenuItem *item = menu->tqfindItem(menu->idAt(0));
+ TQMenuItem *item = menu->findItem(menu->idAt(0));
if (item->popup())
{
diff --git a/kicker/libkicker/panelbutton.cpp b/kicker/libkicker/panelbutton.cpp
index f5e35a2ad..4d60068a8 100644
--- a/kicker/libkicker/panelbutton.cpp
+++ b/kicker/libkicker/panelbutton.cpp
@@ -978,7 +978,7 @@ bool PanelPopupButton::eventFilter(TQObject *, TQEvent *e)
if (e->type() == TQEvent::MouseMove)
{
TQMouseEvent *me = TQT_TQMOUSEEVENT(e);
- if (TQT_TQRECT_OBJECT(rect()).tqcontains(mapFromGlobal(me->globalPos())) &&
+ if (TQT_TQRECT_OBJECT(rect()).contains(mapFromGlobal(me->globalPos())) &&
((me->state() & ControlButton) != 0 ||
(me->state() & ShiftButton) != 0))
{
@@ -990,7 +990,7 @@ bool PanelPopupButton::eventFilter(TQObject *, TQEvent *e)
e->type() == TQEvent::MouseButtonDblClick)
{
TQMouseEvent *me = TQT_TQMOUSEEVENT(e);
- if (TQT_TQRECT_OBJECT(rect()).tqcontains(mapFromGlobal(me->globalPos())))
+ if (TQT_TQRECT_OBJECT(rect()).contains(mapFromGlobal(me->globalPos())))
{
m_pressedDuringPopup = true;
return true;
@@ -999,7 +999,7 @@ bool PanelPopupButton::eventFilter(TQObject *, TQEvent *e)
else if (e->type() == TQEvent::MouseButtonRelease)
{
TQMouseEvent *me = TQT_TQMOUSEEVENT(e);
- if (TQT_TQRECT_OBJECT(rect()).tqcontains(mapFromGlobal(me->globalPos())))
+ if (TQT_TQRECT_OBJECT(rect()).contains(mapFromGlobal(me->globalPos())))
{
if (m_pressedDuringPopup && m_popup)
{
diff --git a/kicker/menuext/kate/katesessionmenu.cpp b/kicker/menuext/kate/katesessionmenu.cpp
index 860f6d04a..7326d8fb0 100644
--- a/kicker/menuext/kate/katesessionmenu.cpp
+++ b/kicker/menuext/kate/katesessionmenu.cpp
@@ -124,7 +124,7 @@ void KateSessionMenu::slotExec( int id )
"kate_session_button_create_anonymous" ) == KMessageBox::No )
return;
- if ( m_sessions.tqcontains( name ) &&
+ if ( m_sessions.contains( name ) &&
KMessageBox::warningYesNo( 0,
i18n("You allready have a session named %1. Do you want to open that session?").arg( name ),
i18n("Session exists") ) == KMessageBox::No )
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.cpp b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
index b53899a89..1643195e8 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
@@ -112,7 +112,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
bm = parentBookmark.next(bm) )
{
TQString text = bm.text();
- text.tqreplace( '&', "&&" );
+ text.replace( '&', "&&" );
if ( !separatorInserted && m_bIsRoot) { // inserted before the first konq bookmark, to avoid the separator if no konq bookmark
m_parentMenu->insertSeparator();
separatorInserted = true;
diff --git a/kicker/menuext/prefmenu/prefmenu.cpp b/kicker/menuext/prefmenu/prefmenu.cpp
index 3b68c0529..3f50e5275 100644
--- a/kicker/menuext/prefmenu/prefmenu.cpp
+++ b/kicker/menuext/prefmenu/prefmenu.cpp
@@ -84,7 +84,7 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
{
if (!suppressGenericNames ||
- !suppressGenericNames->tqcontains(s->untranslatedGenericName()))
+ !suppressGenericNames->contains(s->untranslatedGenericName()))
{
serviceName = TQString("%1 (%2)").arg(serviceName).arg(comment);
}
@@ -120,7 +120,7 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
// item names may contain ampersands. To avoid them being converted
// to accelerators, replace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ serviceName.replace("&", "&&");
int newId = insertItem(KickerLib::menuIconSet(s->icon()), serviceName, nId, nIndex);
m_entryMap.insert(newId, static_cast<KSycocaEntry*>(s));
@@ -155,7 +155,7 @@ void PrefMenu::mouseMoveEvent(TQMouseEvent * ev)
return;
}
- if (!m_entryMap.tqcontains(id))
+ if (!m_entryMap.contains(id))
{
kdDebug(1210) << "Cannot find service with menu id " << id << endl;
return;
@@ -224,7 +224,7 @@ void PrefMenu::dragEnterEvent(TQDragEnterEvent *event)
void PrefMenu::dragLeaveEvent(TQDragLeaveEvent */*event*/)
{
// see PrefMenu::dragEnterEvent why this is nescessary
- if (!TQT_TQRECT_OBJECT(frameGeometry()).tqcontains(TQCursor::pos()))
+ if (!TQT_TQRECT_OBJECT(frameGeometry()).contains(TQCursor::pos()))
{
KURLDrag::setTarget(0);
}
@@ -297,7 +297,7 @@ void PrefMenu::initialize()
// Item names may contain ampersands. To avoid them being converted
// to accelerators, replace each ampersand with two ampersands.
- groupCaption.tqreplace("&", "&&");
+ groupCaption.replace("&", "&&");
PrefMenu* m = new PrefMenu(g->name(), g->relPath(), this);
m->setCaption(groupCaption);
@@ -323,7 +323,7 @@ void PrefMenu::initialize()
void PrefMenu::slotExec(int id)
{
- if (!m_entryMap.tqcontains(id))
+ if (!m_entryMap.contains(id))
{
return;
}
diff --git a/kicker/menuext/recentdocs/recentdocsmenu.cpp b/kicker/menuext/recentdocs/recentdocsmenu.cpp
index 381ce3fa9..cb26e4cae 100644
--- a/kicker/menuext/recentdocs/recentdocsmenu.cpp
+++ b/kicker/menuext/recentdocs/recentdocsmenu.cpp
@@ -72,17 +72,17 @@ void RecentDocsMenu::initialize() {
// Make sure this entry is not already present in the menu
alreadyPresentInMenu = 0;
for ( TQStringList::Iterator previt = previousEntries.begin(); previt != previousEntries.end(); ++previt ) {
- if (TQString::localeAwareCompare(*previt, f.readName().tqreplace('&', TQString::fromAscii("&&") )) == 0) {
+ if (TQString::localeAwareCompare(*previt, f.readName().replace('&', TQString::fromAscii("&&") )) == 0) {
alreadyPresentInMenu = 1;
}
}
if (alreadyPresentInMenu == 0) {
// Add item to menu
- insertItem(SmallIconSet(f.readIcon()), f.readName().tqreplace('&', TQString::fromAscii("&&") ), id++);
+ insertItem(SmallIconSet(f.readIcon()), f.readName().replace('&', TQString::fromAscii("&&") ), id++);
// Append to duplicate checking list
- previousEntries.append(f.readName().tqreplace('&', TQString::fromAscii("&&") ));
+ previousEntries.append(f.readName().replace('&', TQString::fromAscii("&&") ));
}
}
@@ -114,7 +114,7 @@ void RecentDocsMenu::mouseMoveEvent(TQMouseEvent* e) {
if (!(e->state() & Qt::LeftButton))
return;
- if (!TQT_TQRECT_OBJECT(rect()).tqcontains(_mouseDown))
+ if (!TQT_TQRECT_OBJECT(rect()).contains(_mouseDown))
return;
int dragLength = (e->pos() - _mouseDown).manhattanLength();
diff --git a/kicker/menuext/remote/remotemenu.cpp b/kicker/menuext/remote/remotemenu.cpp
index 3547e3f9b..c09f9a825 100644
--- a/kicker/menuext/remote/remotemenu.cpp
+++ b/kicker/menuext/remote/remotemenu.cpp
@@ -93,7 +93,7 @@ void RemoteMenu::initialize()
for(; name!=endf; ++name)
{
- if (!names_found.tqcontains(*name))
+ if (!names_found.contains(*name))
{
names_found.append(*name);
TQString filename = *dirpath+*name;
@@ -124,7 +124,7 @@ void RemoteMenu::openRemoteDir()
void RemoteMenu::slotExec(int id)
{
- if (m_desktopMap.tqcontains(id))
+ if (m_desktopMap.contains(id))
{
new KRun(m_desktopMap[id]);
}
diff --git a/kicker/menuext/system/systemmenu.cpp b/kicker/menuext/system/systemmenu.cpp
index 33eba2558..12ec087d8 100644
--- a/kicker/menuext/system/systemmenu.cpp
+++ b/kicker/menuext/system/systemmenu.cpp
@@ -77,7 +77,7 @@ void SystemMenu::initialize()
void SystemMenu::slotExec(int id)
{
- if(!m_urlMap.tqcontains(id)) return;
+ if(!m_urlMap.contains(id)) return;
new KRun(m_urlMap[id]); // will delete itself
}
diff --git a/kicker/menuext/tom/tom.cc b/kicker/menuext/tom/tom.cc
index 24ab027a8..f2689bc1f 100644
--- a/kicker/menuext/tom/tom.cc
+++ b/kicker/menuext/tom/tom.cc
@@ -239,7 +239,7 @@ void TOM::initializeRecentDocs()
KDesktopFile f(*it, true /* read only */);
m_recentDocsMenu->insertItem(DesktopIcon(f.readIcon(), KIcon::SizeMedium),
- f.readName().tqreplace('&', "&&"), id);
+ f.readName().replace('&', "&&"), id);
++id;
}
}
@@ -302,7 +302,7 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
TQString name = config.readEntry("Name");
// in case the name contains an ampersand, double 'em up
- name.tqreplace("&", "&&");
+ name.replace("&", "&&");
TQString desktopfile = config.readPathEntry("DesktopFile");
KService::Ptr pService = KService::serviceByDesktopPath(desktopfile);
@@ -551,10 +551,10 @@ void TOM::initialize()
if (userInfo)
{
username = TQString::fromLocal8Bit(userInfo->pw_gecos);
- if (username.tqfind(',') != -1)
+ if (username.find(',') != -1)
{
// Remove everything from and including first comma
- username.truncate(username.tqfind(','));
+ username.truncate(username.find(','));
}
if (username.isEmpty())
@@ -583,7 +583,7 @@ void TOM::contextualizeRMBmenu(KPopupMenu* menu, int menuItem, TQPopupMenu* ctxM
ctxMenu->removeItem(contextMenuTitleID);
TQString text = menu->text(menuItem);
- int parens = text.tqfind('(') - 1;
+ int parens = text.find('(') - 1;
if (parens > 0)
{
text = text.left(parens);
@@ -775,7 +775,7 @@ TQMouseEvent TOM::translateMouseEvent( TQMouseEvent* e )
{
TQRect side = sideImageRect();
- if ( !side.tqcontains( e->pos() ) )
+ if ( !side.contains( e->pos() ) )
return *e;
TQPoint newpos( e->pos() );
@@ -824,7 +824,7 @@ void TOM::runCommand()
void TOM::runTask(int id)
{
- if (!m_tasks.tqcontains(id)) return;
+ if (!m_tasks.contains(id)) return;
kapp->propagateSessionManager();
KApplication::startServiceByDesktopPath(m_tasks[id]->desktopEntryPath(),
diff --git a/kicker/taskbar/taskbar.cpp b/kicker/taskbar/taskbar.cpp
index 33109c576..4da304daf 100644
--- a/kicker/taskbar/taskbar.cpp
+++ b/kicker/taskbar/taskbar.cpp
@@ -358,7 +358,7 @@ void TaskBar::add(Startup::Ptr startup)
it != containers.end();
++it)
{
- if ((*it)->tqcontains(startup))
+ if ((*it)->contains(startup))
{
return;
}
@@ -372,7 +372,7 @@ void TaskBar::add(Startup::Ptr startup)
void TaskBar::showTaskContainer(TaskContainer* container)
{
- TaskContainer::List::iterator it = m_hiddenContainers.tqfind(container);
+ TaskContainer::List::iterator it = m_hiddenContainers.find(container);
if (it != m_hiddenContainers.end())
{
m_hiddenContainers.erase(it);
@@ -432,7 +432,7 @@ void TaskBar::remove(Task::Ptr task, TaskContainer* container)
it != m_hiddenContainers.end();
++it)
{
- if ((*it)->tqcontains(task))
+ if ((*it)->contains(task))
{
(*it)->finish();
m_deletableContainers.append(*it);
@@ -447,7 +447,7 @@ void TaskBar::remove(Task::Ptr task, TaskContainer* container)
it != containers.end();
++it)
{
- if ((*it)->tqcontains(task))
+ if ((*it)->contains(task))
{
container = *it;
break;
@@ -464,7 +464,7 @@ void TaskBar::remove(Task::Ptr task, TaskContainer* container)
if (container->isEmpty())
{
- TaskContainer::List::iterator it = containers.tqfind(container);
+ TaskContainer::List::iterator it = containers.find(container);
if (it != containers.end())
{
containers.erase(it);
@@ -490,7 +490,7 @@ void TaskBar::remove(Startup::Ptr startup, TaskContainer* container)
it != m_hiddenContainers.end();
++it)
{
- if ((*it)->tqcontains(startup))
+ if ((*it)->contains(startup))
{
(*it)->remove(startup);
@@ -511,7 +511,7 @@ void TaskBar::remove(Startup::Ptr startup, TaskContainer* container)
it != containers.end();
++it)
{
- if ((*it)->tqcontains(startup))
+ if ((*it)->contains(startup))
{
container = *it;
break;
@@ -530,7 +530,7 @@ void TaskBar::remove(Startup::Ptr startup, TaskContainer* container)
return;
}
- TaskContainer::List::iterator it = containers.tqfind(container);
+ TaskContainer::List::iterator it = containers.find(container);
if (it != containers.end())
{
containers.erase(it);
@@ -580,7 +580,7 @@ void TaskBar::windowChanged(Task::Ptr task)
{
TaskContainer* c = *it;
- if (c->tqcontains(task))
+ if (c->contains(task))
{
container = c;
break;
@@ -620,7 +620,7 @@ void TaskBar::windowChangedGeometry(Task::Ptr task)
++it)
{
TaskContainer* c = *it;
- if (c->tqcontains(task))
+ if (c->contains(task))
{
container = c;
break;
diff --git a/kicker/taskbar/taskcontainer.cpp b/kicker/taskbar/taskcontainer.cpp
index 7da0cd50e..5b084a962 100644
--- a/kicker/taskbar/taskcontainer.cpp
+++ b/kicker/taskbar/taskcontainer.cpp
@@ -390,7 +390,7 @@ void TaskContainer::remove(Startup::Ptr startup)
}
}
-bool TaskContainer::tqcontains(Task::Ptr task)
+bool TaskContainer::contains(Task::Ptr task)
{
if (!task)
{
@@ -408,12 +408,12 @@ bool TaskContainer::tqcontains(Task::Ptr task)
return false;
}
-bool TaskContainer::tqcontains(Startup::Ptr startup)
+bool TaskContainer::contains(Startup::Ptr startup)
{
return startup && (m_startup == startup);
}
-bool TaskContainer::tqcontains(WId win)
+bool TaskContainer::contains(WId win)
{
Task::List::iterator itEnd = tasks.end();
for (Task::List::iterator it = tasks.begin(); it != itEnd; ++it)
@@ -638,7 +638,7 @@ void TaskContainer::drawButton(TQPainter *p)
// modified overlay
static TQString modStr = "[" + i18n( "modified" ) + "]";
- int modStrPos = text.tqfind( modStr );
+ int modStrPos = text.find( modStr );
int textPos = ( taskBar->showIcon() && (!pixmap.isNull() || m_startup)) ? 2 + 16 + 2 : 0;
if (modStrPos >= 0)
@@ -944,7 +944,7 @@ void TaskContainer::mouseReleaseEvent(TQMouseEvent *e)
// This is to avoid the flicker caused by redrawing the
// button as unpressed just before it's activated.
- if (!TQT_TQRECT_OBJECT(rect()).tqcontains(e->pos()))
+ if (!TQT_TQRECT_OBJECT(rect()).contains(e->pos()))
{
TQToolButton::mouseReleaseEvent(e);
return;
@@ -1623,7 +1623,7 @@ void TaskContainer::updateKickerTip(KickerTip::Data& data)
details.append(i18n("Has unsaved changes"));
static TQString modStr = "[" + i18n( "modified" ) + "]";
- int modStrPos = name.tqfind(modStr);
+ int modStrPos = name.find(modStr);
if (modStrPos >= 0)
{
diff --git a/kicker/taskbar/taskcontainer.h b/kicker/taskbar/taskcontainer.h
index 4d2e0de9b..8dfdf6d2d 100644
--- a/kicker/taskbar/taskcontainer.h
+++ b/kicker/taskbar/taskcontainer.h
@@ -57,9 +57,9 @@ public:
void remove(Task::Ptr);
void remove(Startup::Ptr);
- bool tqcontains(Task::Ptr);
- bool tqcontains(Startup::Ptr);
- bool tqcontains(WId);
+ bool contains(Task::Ptr);
+ bool contains(Startup::Ptr);
+ bool contains(WId);
bool isEmpty();
bool onCurrentDesktop();
diff --git a/kicker/taskmanager/tasklmbmenu.cpp b/kicker/taskmanager/tasklmbmenu.cpp
index fd344f0d2..af7f6e854 100644
--- a/kicker/taskmanager/tasklmbmenu.cpp
+++ b/kicker/taskmanager/tasklmbmenu.cpp
@@ -111,7 +111,7 @@ void TaskLMBMenu::fillMenu()
{
Task::Ptr t = (*it);
- TQString text = t->visibleName().tqreplace("&", "&&");
+ TQString text = t->visibleName().replace("&", "&&");
TaskMenuItem *menuItem = new TaskMenuItem(text,
t->isActive(),
diff --git a/kicker/taskmanager/taskmanager.cpp b/kicker/taskmanager/taskmanager.cpp
index 103205042..3b2316e4d 100644
--- a/kicker/taskmanager/taskmanager.cpp
+++ b/kicker/taskmanager/taskmanager.cpp
@@ -247,9 +247,9 @@ Task::Ptr TaskManager::findTask(int desktop, const TQPoint& p)
continue;
}
- if (t->geometry().tqcontains(p))
+ if (t->geometry().contains(p))
{
- int index = list.tqfindIndex(t->window());
+ int index = list.findIndex(t->window());
if (index > currentIndex)
{
currentIndex = index;
@@ -295,7 +295,7 @@ void TaskManager::windowAdded(WId w )
WId transient_for = (WId) transient_for_tmp;
// check if it's transient for a skiptaskbar window
- if( _skiptaskbar_windows.tqcontains( transient_for ))
+ if( _skiptaskbar_windows.contains( transient_for ))
return;
// lets see if this is a transient for an existing task
@@ -807,7 +807,7 @@ bool Task::isModified() const
static TQString modStr = TQString::fromUtf8("[") +
i18n("modified") +
TQString::fromUtf8("]");
- int modStrPos = _info.visibleName().tqfind(modStr);
+ int modStrPos = _info.visibleName().find(modStr);
return ( modStrPos != -1 );
}
@@ -831,7 +831,7 @@ void Task::updateDemandsAttentionState( WId w )
NETWinInfo i( qt_xdisplay(), w, qt_xrootwin(), NET::WMState );
if(i.state() & NET::DemandsAttention)
{
- if (!_transients_demanding_attention.tqcontains(w))
+ if (!_transients_demanding_attention.contains(w))
{
_transients_demanding_attention.append(w);
}
@@ -984,10 +984,10 @@ bool Task::idMatch( const TQString& id1, const TQString& id2 )
if ( id1.isEmpty() || id2.isEmpty() )
return false;
- if ( id1.tqcontains( id2 ) > 0 )
+ if ( id1.contains( id2 ) > 0 )
return true;
- if ( id2.tqcontains( id1 ) > 0 )
+ if ( id2.contains( id1 ) > 0 )
return true;
return false;
diff --git a/kicker/taskmanager/taskmanager.h b/kicker/taskmanager/taskmanager.h
index a12a062d1..ddd5327d2 100644
--- a/kicker/taskmanager/taskmanager.h
+++ b/kicker/taskmanager/taskmanager.h
@@ -282,7 +282,7 @@ public:
//* @internal
void removeTransient( WId w );
//* @internal
- bool hasTransient(WId w) const { return _transients.tqfind(w) != _transients.end(); }
+ bool hasTransient(WId w) const { return _transients.find(w) != _transients.end(); }
//* @internal
void updateDemandsAttentionState( WId w );
//* @internal
diff --git a/kicker/taskmanager/taskrmbmenu.cpp b/kicker/taskmanager/taskrmbmenu.cpp
index bb5ee6035..fb4c9ae87 100644
--- a/kicker/taskmanager/taskrmbmenu.cpp
+++ b/kicker/taskmanager/taskrmbmenu.cpp
@@ -236,7 +236,7 @@ TQPopupMenu* TaskRMBMenu::makeDesktopsMenu(Task::Ptr t)
m->insertSeparator();
for (int i = 1; i <= TaskManager::the()->numberOfDesktops(); i++) {
- TQString name = TQString("&%1 %2").arg(i).arg(TaskManager::the()->desktopName(i).tqreplace('&', "&&"));
+ TQString name = TQString("&%1 %2").arg(i).arg(TaskManager::the()->desktopName(i).replace('&', "&&"));
id = m->insertItem( name, t, TQT_SLOT( toDesktop(int) ) );
m->setItemParameter( id, i );
m->setItemChecked( id, !t->isOnAllDesktops() && t->desktop() == i );
@@ -256,7 +256,7 @@ TQPopupMenu* TaskRMBMenu::makeDesktopsMenu()
m->insertSeparator();
for (int i = 1; i <= TaskManager::the()->numberOfDesktops(); i++) {
- TQString name = TQString("&%1 %2").arg(i).arg(TaskManager::the()->desktopName(i).tqreplace('&', "&&"));
+ TQString name = TQString("&%1 %2").arg(i).arg(TaskManager::the()->desktopName(i).replace('&', "&&"));
id = m->insertItem( name, this, TQT_SLOT( slotAllToDesktop(int) ) );
m->setItemParameter( id, i );
}
diff --git a/kicker/kicker/core/container_extension.cpp b/kicker/kicker/core/container_extension.cpp
index a4e9f0634..c2023b7df 100644
--- a/kicker/kicker/core/container_extension.cpp
+++ b/kicker/kicker/core/container_extension.cpp
@@ -680,7 +680,7 @@ void ExtensionContainer::unhideTriggered(UnhideTrigger::Trigger tr, int Xinerama
// Otherwise hide mode is automatic. The code below is slightly
// complex so as to keep the same behavior as it has always had:
// only unhide when the cursor position is within the widget geometry.
// We can't just do geometry().tqcontains(TQCursor::pos()) because
// now we hide the panel completely off screen.
int x = TQCursor::pos().x();
@@ -754,7 +754,7 @@ void ExtensionContainer::autoHideTimeout()
TQRect r = geometry();
TQPoint p = TQCursor::pos();
- if (!r.tqcontains(p) &&
+ if (!r.contains(p) &&
(m_settings.unhideLocation() == UnhideTrigger::None ||
!shouldUnhideForTrigger(m_unhideTriggeredAt)))
{
@@ -680,7 +680,7 @@ void ExtensionContainer::unhideTriggered(UnhideTrigger::Trigger tr, int Xinerama
// complex so as to keep the same behavior as it has always had:
// only unhide when the cursor position is within the widget geometry.
- // We can't just do geometry().tqcontains(TQCursor::pos()) because
+ // We can't just do geometry().contains(TQCursor::pos()) because
// now we hide the panel completely off screen.
int x = TQCursor::pos().x();